@@ -1,14 +1,14 @@
 library(lfe)
-options(lfe.threads=1)
+options(lfe.threads=2,digits=5,warn=1)
 set.seed(655320)
-x <- rnorm(50000,mean=200)
+x <- rnorm(5000,mean=200)
 x2 <- rnorm(length(x))
 x3 <- rexp(length(x))
 ## create individual and firm
-id <- factor(sample(15000,length(x),replace=TRUE))
-firm <- factor(sample(13000,length(x),replace=TRUE))
-shoe <- factor(sample(1000,length(x),replace=TRUE))
-shirt <- factor(sample(1000,length(x),replace=TRUE))
+id <- factor(sample(1500,length(x),replace=TRUE))
+firm <- factor(sample(1300,length(x),replace=TRUE))
+shoe <- factor(sample(100,length(x),replace=TRUE))
+shirt <- factor(sample(100,length(x),replace=TRUE))
 ## effects
 id.eff <- rnorm(nlevels(id))
 firm.eff <- rnorm(nlevels(firm))
@@ -18,7 +18,7 @@ shirt.eff <- rnorm(nlevels(shirt))
 y <- x + 0.25*x2 + 0.5*x3 + id.eff[id] + firm.eff[firm] + shoe.eff[shoe] + shirt.eff[shirt] + rnorm(length(x))
 
 ## estimate
-summary(est <- felm(y ~ x+x2 + x3 + G(id) + G(firm) + G(shoe) + G(shirt)))
+summary(est <- felm(y ~ x+x2 + x3 |id+firm+shoe+shirt))
 cat('Components:',nlevels(est$cfactor),'largest:',sum(est$cfactor == '1'),'\n')
 ## extract the group fixed effects
   ## verify that id and firm coefficients are 1
